@@ -114,7 +114,7 @@
     (dv       "Didier Verna"      "didier@xemacs.org")
     (eb       "Eric Benson"       "eb@xemacs.org")
     (fabrice  "Fabrice Popineau"  "fabrice@xemacs.org")
-    (golubev  "I N Golubev"       "golubev@xemacs.org")
+    (golubev  "Ilya Golubev"      "golubev@xemacs.org")
     (gunnar   "Gunnar Evermann"   "gunnar@xemacs.org")
     (hbs      "Harlan Sexton"     "hbs@xemacs.org")
     (hisashi  "Hisashi Miyashita" "hisashi@xemacs.org")
@@ -150,7 +150,7 @@
     (rose     "John Rose"         "rose@xemacs.org")
     (rossini  "Anthony Rossini"   "rossini@xemacs.org")
     (slb      "Steve Baur"        "steve@xemacs.org")
-    (sperber  "Michael Sperber"   "sperber@xemacs.org")
+    (sperber  "Michael Sperber"   "mike@xemacs.org")
     (stig     "Jonathan Stigelman" "stig@xemacs.org")
     (stigb    "Stig Bjorlykke"    "stigb@xemacs.org")
     (thiessel "Marcus Thiessel"   "marcus@xemacs.org")
@@ -188,7 +188,8 @@
     ;; to sort the stuff below, use M-x sort-regexp-fields RET
     ;; ^.*$ RET (\([a-z]*\) RET
   '((ajc        . "http://www-personal.monash.edu.au/~ajc/")
-    (baw        . "http://www.python.org/~bwarsaw/")
+    (alastair   . "http://website.lineone.net/~ajhoughton/")
+    (baw        . "http://barry.wooz.org/")
     (ben        . "http://www.666.com/ben/")
     (ben-xemacs . "http://www.xemacs.org/Architecting-XEmacs/index.html")
     (beopen     . "http://www.beopen.com/")
@@ -198,8 +199,10 @@
     (dkindred   . "http://www.cs.cmu.edu/People/dkindred/me.html")
     (dmoore     . "http://oj.egbt.org/dmoore/")
     (dv         . "http://www.lrde.epita.fr/~didier/")
+    (fabrice    . "http://www.ese-metz.fr/~popineau/")
+    (fptex      . "http://www.fptex.org/")
     (jason      . "http://www.mastaler.com/")
-    (juhp       . "http://www.kurims.kyoto-u.ac.jp/~petersen/")
+    (juhp       . "http://www.01.246.ne.jp/~juhp/")
     (jwz        . "http://www.jwz.org/")
     (kazz       . "http://www.imasy.or.jp/~kazz/")
     (kyle       . "http://www.wonderworks.com/kyle/")
@@ -207,35 +210,49 @@
     (marcpa     . "http://www.positron911.com/products/power.htm")
     (ograf      . "http://www.fga.de/~ograf/")
     (pez        . "http://cbs.sportsline.com/")
-    (piper      . "http://www.xemacs.freeserve.co.uk/")
+    (piper      . "http://www.andypiper.com/")
+    (rossini    . "http://faculty.washington.edu/rossini/")
     (stigb      . "http://www.tihlde.hist.no/~stigb/")
     (vin        . "http://www.upa.org/")
     (vladimir   . "http://www.leonora.org/~vladimir/")
-    (wget       . "http://www.wget.org/")
-    (wget-ftp   . "ftp://gnjilux.cc.fer.hr/pub/unix/util/wget/")
-    (xemacs     . "http://www.xemacs.org/"))
+    (wget       . "http://sunsite.dk/wget/")
+    (xemacs     . "http://www.xemacs.org/")
+    (youngs     . "http://eicq.sourceforge.net/"))
   "Some of the more important URLs.")
 
 (defvar about-left-margin 3)
 
-;; Insert a URL link to the buffer.
-(defun about-url-link (what &optional echo)
-  (or (stringp what)
-      (setq what (cdr (assq what about-url-alist))))
-  (assert what)
+(defun about-lookup-url (name)
+  (let ((result (cdr (assq name about-url-alist))))
+    (assert result)
+    result))
+
+;; Insert a URL link in the buffer.  TEXT-TO-INSERT is the text that will
+;; be hyperlinked; if omitted, the URL is used.  HELP-ECHO is some text that
+;; will be displayed when the mouse moves over the link.
+(defun about-url-link (url &optional text-to-insert help-echo)
+  (assert url)
+  (when (symbolp url)
+    (setq url (about-lookup-url url)))
+  (when (and text-to-insert (symbolp text-to-insert))
+    (setq text-to-insert (about-lookup-url text-to-insert)))
   (widget-create 'url-link
 		 :button-prefix ""
 		 :button-suffix ""
-		 :help-echo echo
-		 what))
+		 :help-echo help-echo
+		 :tag (or text-to-insert url)
+		 url))
 
-;; Insert a mailto: link to the buffer.
+;; Insert a mail link in the buffer.
 (defun about-mailto-link (address)
-  (widget-create 'url-link :help-echo (concat "Send mail to " address)
-		 :button-prefix ""
-		 :button-suffix ""
-		 :tag address
-		 (concat "mailto:" address)))
+  (lexical-let ((address address))
+    (widget-create 'link
+		   :tag address
+		   :button-prefix ""
+		   :button-suffix ""
+		   :action (lambda (widget &optional event)
+			     (compose-mail address))
+		   :help-echo (format "Send mail to %s" address))))
 
 ;; Attach a face to a string, in order to be inserted into the buffer.
 ;; Make sure that the extent is duplicable, but unique.  Returns the
@@ -279,19 +296,33 @@
 	 nil)))
 
 ;; Set up the stuff needed by widget.  Allowed types are `bury' and
-;; `kill'.
+;; `kill'.  The reason why we offer both types is performance: when a
+;; large buffer is merely buried, `about' will find it again when the
+;; user requests it, instead of recreating it.  Small buffers can be
+;; killed because it is cheap to generate their contents.
+
 (defun about-finish-buffer (&optional type)
   (or type (setq type 'bury))
   (widget-insert "\n")
   (if (eq type 'bury)
-      (widget-create 'link :help-echo "Bury buffer"
-		     :action (lambda (&rest ignore)
-			       (bury-buffer))
-		     "Remove")
-    (widget-create 'link :help-echo "Kill buffer"
-		   :action (lambda (&rest ignore)
-			     (kill-buffer (current-buffer)))
-		   "Kill"))
+      (widget-create 'link
+		     :help-echo "Bury this buffer"
+		     :action (lambda (widget event)
+			       (if event
+				   ;; For some reason,
+				   ;; (bury-buffer (event-buffer event))
+				   ;; doesn't work.
+				   (with-selected-window (event-window event)
+				     (bury-buffer))
+				 (bury-buffer)))
+		     :tag "Bury")
+    (widget-create 'link
+		   :help-echo "Kill this buffer"
+		   :action (lambda (widget event)
+			     (if event
+				 (kill-buffer (event-buffer event))
+			       (kill-buffer (current-buffer))))
+		   :tag "Kill"))
   (widget-insert " this buffer and return to previous.\n")
   (use-local-map (make-sparse-keymap))
   (set-keymap-parent (current-local-map) widget-keymap)
@@ -387,7 +418,7 @@ be obtained through the ")
      " on-line information system.\n
 The XEmacs web page can be browsed, using any WWW browser at\n
 \t\t    ")
-    (about-url-link 'xemacs "Visit XEmacs WWW page")
+    (about-url-link 'xemacs nil "Visit XEmacs WWW page")
     (widget-insert "\n
 Note that W3 (XEmacs's own browser), might need customization (due to
 firewalls) in order to work correctly.
@@ -722,27 +753,77 @@ et. al., he spends his time pursuing, among other things, a Life.
 Some of this currently involves doing an A-Z (by country) of
 restaurants with friends, and has, in the past, involved dyeing his
 hair various colours (see ")
-     (about-url-link 'ajc "Visit Andrew's home page")
+     (about-url-link 'ajc nil "Visit Andrew's home page")
      (widget-insert ".\n"))
     (alastair
      (widget-insert
       "\
-Sorry, no personal information available about me yet.\n"))
+Alastair, apart from being an all-round hacker, occasional contributor
+to free software projects and general good egg(!), currently works for
+Telsis, a manufacturer of telephony equipment on the south coast of
+England.  He'd quite like to have his own company one day, but has yet
+to think of that killer product...
+
+See also ")
+        (about-url-link 'alastair nil "Visit Alastair's home page")
+        (widget-insert ".\n"))
     (baw
      (widget-insert "\
-Daddy
-\(C) 1994 Warsaw
-===============
-Drive me Daddy, drive me quick
-Push my pedal, shift my stick
-Fill me up with golden gas
-My rubber squeals, I go real fast
+As of November 2000, I am a software engineer with the Pythonlabs at
+Digital Creations.  Pythonlabs is the core team developing and
+maintaining the Python open source, object-oriented scripting
+language.  Digital Creations is the publisher of Zope, an open source
+content management system written in Python.
 
-Milk me Daddy, milk me now
-Milk me like a big ol' cow
-I've got milk inside my udder
-Churn it up and make some butter\n\nSee also:\n\n\t")
-     (about-url-link 'baw "Visit Barry's home page")
+In addition to my Python and Zope work, I am lead developer for the
+GNU Mailman project, a mailing list management system written,
+naturally, in Python.  See the trend?
+
+On the side I play bass with a number of Washington DC area bands and
+also write poems about cows, milk, and fathers.  Here's a sample, and
+drop me an email if you live in the NYC to Charlotte region; I'll let
+you know when the band's playing in your area.  It'd be cool to meet
+you, and talking about XEmacs would make my wife very happy by helping
+to fend off the legions of groupies that seem to follow me everywhere.
+
+    Milk Me Daddy
+    (C) 1990 Warsaw
+    ===============
+    Oh daddy with your fingers pink 
+    From whose udders do you drink? 
+    Thy milk offends with putrid stink 
+    I'll vomit now, lactose I think 
+
+    If I could dream, I'd be a cow 
+    Not horse, or mule, or barnyard sow 
+    The cud I'd chew would drip and how! 
+    So milk me daddy, milk me now! 
+
+    My bovine nature knows no bounds 
+    I'd naught awake at midnight sounds 
+    Of teens approaching o'er the grounds 
+    To tip with glee, then screech like clowns 
+
+    And so I stare into this glass 
+    Of sweaty juice, I gulp so fast 
+    Each drop I lick, down to the last 
+    The vertigo I know will pass 
+
+    My mother smiles and pats my head 
+    She's proud of me, so she has said 
+    My pop just now gets out of bed 
+    His eyes quite comatose and red 
+
+    He'll empathize my milky fate 
+    Whilest sopping gravy from his plate 
+    And as the hour is getting late 
+    His belly taut with all he ate 
+
+    He isn't often quite so chatty 
+    His arteries clogged with meat so fatty 
+    With burps that launch soup, thick and splatty 
+    Oh how I wish you'd milk me daddy\n\n\t")
+     (about-url-link 'baw nil "Visit Barry's home page")
      (widget-insert "\n"))
     (ben
      (widget-insert
@@ -760,9 +841,9 @@ More recently I have fought my way back with loads and loads of
 narcotic painkillers, and currently I'm an art student at the
 University of Arizona.\n\n")
      (widget-insert "Architecting XEmacs: ")
-     (about-url-link 'ben-xemacs "Find the miracles in store for XEmacs")
+     (about-url-link 'ben-xemacs nil "Find the miracles in store for XEmacs")
      (widget-insert "\nBen's home page:     ")
-     (about-url-link 'ben "Visit Ben's page")
+     (about-url-link 'ben nil "Visit Ben's page")
      (widget-insert "\n"))
     (bw
      (widget-insert "\
@@ -785,23 +866,14 @@ looking for a job involving lisp programming, French and Russian.\n"))
 Sorry, no personal information available about me yet.\n"))
     (cthomp
      (widget-insert "\
-Chuck, through being in the wrong place at the right time, got stuck
-with being Jamie's replacement as the primary maintainer of XEmacs.
-This caused his hair to begin falling out and quadrupled his daily
-coffee dosage.  Though he works at and for the University of Illinois
-his funding for XEmacs work actually came from Sun Microsystems.
-
-He has worked on XEmacs since November 1992, which fact occasionally
-gives him nightmares.  As of October 1995, he no longer works
-full-time on XEmacs, though he does continue as an active maintainer.
-His main contributions have been the greatly enhanced redisplay
-engine, scrollbar support, the toolbars, configure support and
-numerous other features and fixes.
-
-Rumors that Chuck is aka Black Francis aka Frank Black are completely
-unfounded.\n"))
+Chuck is a senior system and network administrator for the Computer
+Science department at the Unversity of Illinois.  In one previous life
+he spent every waking hour working on XEmacs.  In another he dabbled
+as a project manager for a streaming video startup (RIP).  His current
+reason for not having time to contribute to XEmacs is the Thompson
+Twins.\n"))
     (daiki
-     (about-url-link 'daiki "Visit Daiki's page"))
+     (about-url-link 'daiki nil "Visit Daiki's page"))
     (dan
      (widget-insert
       "\
@@ -827,7 +899,7 @@ Carnegie Mellon University, but he's trying hard to kick that
 habit.
 
 See ")
-     (about-url-link 'dkindred "Visit Darrell's WWW page")
+     (about-url-link 'dkindred nil "Visit Darrell's WWW page")
      (widget-insert ".\n"))
     (dmoore
      (widget-insert "\
@@ -839,7 +911,7 @@ of course.)  He can be found at `druidmuck.egbt.org 4201' at various
 hours of the day.
 
 He has a page at ")
-     (about-url-link 'dmoore "Visit David's home page")
+     (about-url-link 'dmoore nil "Visit David's home page")
      (widget-insert ".\n"))
     (dv
      (widget-insert "\
@@ -858,7 +930,7 @@ semi-professional Jazz guitar player (and singer), which means that it
 is not the way I earn my crust, but things may very well reverse in
 the future ...\n\n")
      (widget-insert "Visit Didier's home page: ")
-     (about-url-link 'dv "Visit Didier's home page")
+     (about-url-link 'dv nil "Visit Didier's home page")
      (widget-insert "\n"))
     (eb
      (widget-insert
@@ -867,11 +939,35 @@ Sorry, no personal information available about me yet.\n"))
     (fabrice
      (widget-insert
       "\
-Sorry, no personal information available about me yet.\n"))
+I'm a computer science researcher and teacher in a French electrical
+engineering institution called Supelec. My fields of interest are
+symbolic artificial intelligence, theoretical computer science, functional
+languages ... and TeX.
+
+Lately, my hacking time has been devoted to porting the Web2C/teTeX
+distribution of TeX for Unix to Win32, and I'm still maintaining it.
+It is included in the TeX Live cdrom edited by Sebastian Rahtz.\n")
+     (widget-insert "Visit fpTeX home page: ")
+     (about-url-link 'fptex nil "Visit fpTeX home page")
+     (widget-insert "\nFabrice's home page:   ")
+     (about-url-link 'fabrice nil "Visit Fabrice's page")
+     (widget-insert "\n"))
     (golubev
      (widget-insert
       "\
-Sorry, no personal information available about me yet.\n"))
+I appreciate power of XEmacs, but elementary editing operations should
+be done by single keystrokes with no modifiers.  So would not use
+XEmacs until discovered viper, and now can't live without viper.
+Occasionally dislike something in there or in other free software, and
+try to get it fixed.  .plan file contains classic (perhaps reinvented
+independently) formula:
+
+Hacking world for ever
+
+(borrowed from \"Hacking X for Y\" in ")
+     (about-url-link "http://www.jargon.org/"
+		     "Jargon File" "www.jargon.org")
+     (widget-insert ").\n"))
     (gunnar
      (widget-insert
       "\
@@ -890,16 +986,39 @@ Sorry, no personal information available about me yet.\n"))
 Sorry, no personal information available about me yet.\n"))
     (hniksic
      (widget-insert "\
-Hrvoje is a student at the Faculty of Electrical Engineering and
-Computing in Zagreb, Croatia, working part-time at system administration
-at SRCE.  His hobby is hacking free software, particularly XEmacs and
-GNU Wget, the latter being his very own creation.
+Hrvoje thinks he works in the server-side web business.  In reality,
+he cranks out huge quantities of HTML, Tcl, and Java for the German
+branch of ")
+     (about-url-link "http://www.arsdigita.com/"
+		     "ArsDigita, Inc." "www.arsdigita.com")
+     ;; Avoid literal I18N characters in strings.  *Displaying* a
+     ;; Latin 1 character should always be safe, though, with or
+     ;; without Mule.
+     (let ((muenchen (format "M%cnchen" (make-char 'latin-iso8859-1 252))))
+       (widget-insert (format "\
+  He joined the ranks of Gastarbeiters only
+recently; he is trying to learn German and get attuned to %s
+and Bav^H^H^HGermany.\n" muenchen)))
 
-For info on Wget, see ")
-     (about-url-link 'wget "Visit the Wget web page")
-     (widget-insert " or\n")
-     (about-url-link 'wget-ftp "Visit the Wget ftp page")
-     (widget-insert ".\n"))
+     (widget-insert "\
+
+Before ArsDigita, he worked as a programmer at ")
+     (about-url-link "http://www.iskon.hr/" "Iskon," "www.iskon.hr")
+     (widget-insert " a fast-growing
+Croatian ISP.  Even before that, he worked part-time for academic
+institutions like ")
+     (about-url-link "http://www.srce.hr/" "SRCE" "www.srce.hr")
+     (widget-insert " and ")
+     (about-url-link "http://www.carnet.hr/" "CARNet," "www.carnet.hr")
+     (widget-insert " and tried to attend university.
+
+He takes perverse pleasure in building and maintaining free software
+in his free time.  Apart from XEmacs, his major contribution is ")
+     (about-url-link 'wget "Wget," "Wget home page")
+     (widget-insert "
+his very own creation, now jointly maintained by a happy crew.
+
+He dreams of having a home page.\n"))
     (hobley
      (widget-insert "\
 I used to do real work, but now I am a Project Manager for one of the
@@ -939,16 +1058,17 @@ Scientist(tm) in the Los Alamos National Laboratory's Advanced
 Computing Group.
 
 See: ")
-      (about-url-link 'jason "Visit Jason's homepage")
+      (about-url-link 'jason nil "Visit Jason's homepage")
       (widget-insert ".\n"))
     (jens
      (widget-insert "\
-I'm currently working at the University of Karlsruhe, Germany on
-getting my diploma thesis on Supersymmetry (uuh, that's physics) done.
-After that (and all the remaining exams) I'm looking forward to make a
-living out of my hobbies -- computers (and graphics). But because I
-have no deadline for the exams and XEmacs betas are released at a high
-rate this may take some time...\n"))
+I'm currently working for 1&1 Internet AG, a large Domain and Webspace
+Provider in Germany and Europe.  I do mostly Java/XML/OO/Component
+stuff today.  I'm interested EJB, Corba and other middleware or
+distributed Systems.  Besides work, I occasionally hack on The Gimp
+and other gtk/gnome related projects.  Maybe the advent of XEmacs/Gtk
+will get me back to spend some time again hacking on XEmacs in the
+near future.\n"))
     (jmiller
      (widget-insert "\
 Jeff grew up in Indiana and is a country boy at heart.  He currently
@@ -969,38 +1089,43 @@ until late 1997 when I started working at Symbian, a Windows-only
 company, and felt lost without my favourite editing environment.\n"))
     (juhp
      (widget-insert "\
-I started using XEmacs-20 as my work-environment in June 1997.  I
-became a beta developer shortly after that (\"it seems like a good
-idea at the time...\" :-), so far contributing mainly bug fixes,
-\"find-func.el\" and improvements to \"help.el\".
+Jens was born in Copenhagen, grew up in Britain and is now living in
+Japan.  He started using XEmacs 20 (instead of Emacs) as his
+work-environment in June 1997 while still an EU postdoc at RIMS, Kyoto
+University, and quickly got involved in XEmacs development.  Recently
+he is getting into Haskell, a very nice pure functional programming
+language.
 
-My current dreams for XEmacs: Move to using guile as the Lisp engine
-and gtk as the default X toolkit.
-
-I have been a postdoctoral researcher at the Research Institute for
-Mathematical Sciences, Kyoto University, since August 1994, doing
-research in mathematical physics (representation theory of quantum
-groups).  Though now I seem to be heading for other things.
-
-My homepage is ")
-     (about-url-link 'juhp "Visit Jens' homepage")
-     (widget-insert ".\n"))
+")
+     (about-url-link 'juhp nil "Visit Jens' homepage")
+     (widget-insert "\n"))
     (jwz
      (widget-insert
       "\t"
       (about-with-face "\"So much to do, so little time.\"" 'italic)
       "\n
 Jamie Zawinski was primarily to blame for Lucid Emacs from its
-inception in 1991, to 1994 when Lucid Inc. finally died.  He is now to
-be found at Netscape Communications, hacking on Netscape Navigator (he
-did the first Unix version and the mail and news reader).  Thankfully
-his extensive sleep deprivation experiments conducted during 1994 and
-1995 are now a thing of the past, but his predilection for dark,
-Gothic music remains unabated.
+inception in 1991, to 1994 when Lucid Inc. finally died.  After that,
+he was one of the initial employees of Netscape Communications, writing
+the first Unix version of Netscape Navigator, and designing and
+implementing the first version of the Netscape Mail and News readers.
+He then helped create and run ")
+     (about-url-link "http://www.mozilla.org/"
+		     "mozilla.org"
+		     "Visit The Mozilla Organization")
+     (widget-insert " for its first two years,
+until America Online bought Netscape Communications, at which point he
+gave up in disgust and dropped out of the computer industry entirely.
 
-Come visit his glorified .plan file at\n\n")
-     (about-url-link 'jwz "Visit Jamie's home page")
-     (widget-insert "\n"))
+He now runs a ")
+     (about-url-link "http://www.dnalounge.com/"
+		     "nightclub"
+		     "Visit The DNA Lounge")
+     (widget-insert " in San Francisco, and occasionally writes
+screen savers.\n\n")
+     (widget-insert "Visit jwz's ")
+     (about-url-link 'jwz "home page" "Visit jwz's home page")
+     (widget-insert ".\n"))
     (kazz
      (widget-insert "\
 Kazz is the XEmacs lead on BSD (especially FreeBSD).
@@ -1013,7 +1138,7 @@ In real life, he is working on a PDM product based on CORBA,
 and doing consultation, design and implemention.
 He loves to play soccer, yes football!
 See also:")
-     (about-url-link 'kazz "Visit Kazz's home page")
+     (about-url-link 'kazz nil "Visit Kazz's home page")
      (widget-insert ".\n"))
     (kirill
      (widget-insert
@@ -1022,7 +1147,7 @@ Sorry, no personal information available about me yet.\n"))
     (kyle
      (widget-insert "\
 See\n")
-     (about-url-link 'kyle "Visit Kyle's Home page")
+     (about-url-link 'kyle nil "Visit Kyle's Home page")
      (widget-insert ".\n"))
     (larsi
      (widget-insert "\
@@ -1031,14 +1156,14 @@ Internet stock broker.  He claims no responsibility for the Dot
 Com Bomb, but he snickers a lot.
 
 See ")
-     (about-url-link 'larsi "Visit the Larsissistic pages")
+     (about-url-link 'larsi nil "Visit the Larsissistic pages")
      (widget-insert ".\n"))
     (marcpa
      (widget-insert "\
 I work for Positron Industries Inc., Public Safety Division.
 I'm part of the team producing POWER 911, a 911 emergency response
 system written in Modula3:\n")
-     (about-url-link 'marcpa "Visit POWER 911")
+     (about-url-link 'marcpa nil "Visit POWER 911")
      (widget-insert "\
 \n\nPreviously, I worked at Softimage Inc., now a Microsoft company
 \(eeekkk!), as a UNIX system administrator.  This is where I've been
@@ -1096,59 +1221,75 @@ also Drag'n'Drop, and more), and various other hacks: ISDN-tools,
 cd players, python, etc...
 
 To see some of these have a look at ")
-     (about-url-link 'ograf "one of my homepages")
+     (about-url-link 'ograf nil "one of my homepages")
      (widget-insert ".\n"))
     (olivier
      (widget-insert
       "\
 Sorry, no personal information available about me yet.\n"))
     (oscar
-     (widget-insert
-      "\
-Sorry, no personal information available about me yet.\n"))
+     (widget-insert "\
+Oscar heads the Computer Science department at CPE Lyon, a french
+engineering school in France. Besides his administrative tasks he
+teaches networking basics, Internet technologies (you know, all these
+xxML and hairy script languages !)  and the Scheme language.\n"))
     (pelegri
      (widget-insert
       "\
-Sorry, no personal information available about me yet.\n"))
+I did my PhD at UCB and a postdoc at CSL/PARC.  I joined Sun in 1990,
+spent some time in DevPro (that is when I made my contribution to
+XEmacs) and joined JavaSoft in fall '95, where I've been the lead for
+several JSP-related specifications and JAX-RPC.  I'm currently the Web
+Layer architect for J2EE. 
+
+I was born in Barcelona and I grew up mostly in Caracas; I have two kids
+and I speak only catalan to them; I can juggle some (career, family, and
+4 balls or 3 pins); and my english can be idiosyncratic!.\n"))
     (pez
      (widget-insert "\
 Peter currently serves as Senior Vice President, Product Development
 for CBS SportsLine.  See ")
-     (about-url-link 'pez "CBS SportsLine")
+     (about-url-link 'pez nil "CBS SportsLine")
      (widget-insert ".\n"))
     (piper
      (widget-insert "\
 My home page is here:\n")
-     (about-url-link 'piper "Visit andy's home page")
+     (about-url-link 'piper nil "Visit andy's home page")
      (widget-insert "\n
-Andy has recently rejoined the XEmacs team to help port XEmacs to
-MS Windows operating systems.\n"))
+ Andy has been active in the XEmacs team for a number of years,
+helping port XEmacs to MS Windows operating systems. He is also the
+current MS Windows release manager and maintains the MS Windows
+netinstaller.\n"))
     (pittman
      (widget-insert
       "\
 Sorry, no personal information available about me yet.\n"))
     (rickc
      (widget-insert "\
-The hacker formerly known as Rick Busdiecker develops and maintains
-libraries for financial applications at Lehman Brothers during
-daylight hours.  In the evenings he maintains three children, and
-when he ought to be sleeping he co-maintains ILISP, builds XEmacs
-betas, and tinkers with various personal hacking projects.\n"))
+The hacker formerly known as Rick Busdiecker is a developer and
+technical manager at Deutsche Bank in New York during daylight hours.
+In the evenings he maintains three children, and when he ought to be
+sleeping he builds XEmacs betas, and tinkers with various personal
+hacking projects.\n"))
     (rose
      (widget-insert
       "\
 Sorry, no personal information available about me yet.\n"))
     (rossini
      (widget-insert "\
-Author of the first XEmacs FAQ, as well as minor priest in the
-movement to get every statistician in the world to use XEmacs for
-statistical programming and data analysis.  Current development lead
-for ESS (Emacs Speaks Statistics), a mode and inferior mode for
-statistical programming and data analysis for SAS, S, S-PLUS, R,
-XLispStat; configurable for nearly any other statistical
-language/package one might want.  In spare time, acts as a
-Ph.D. (bio)statistician for money and amusement.  Current position:
-Assistant Professor of Statistics at the University of South Carolina.\n"))
+Current development lead for ESS (Emacs Speaks Statistics), a mode and
+inferior mode for statistical programming and data analysis for SAS,
+S, S-PLUS, R, XLispStat; configurable for nearly any other statistical
+language/package one might want.  In spare time, chases his son around
+and acts as a Ph.D. (bio)statistician for money and amusement,
+primarily focusing on statistical computing, visualization, and the
+design and analysis of HIV vaccine trials.  Current position: Research
+Assistant Professor of Biostatistics at the University of Washington
+and the Fred Hutchinson Cancer Research Center.
+
+See ")
+     (about-url-link 'rossini nil "Visit Anothony's home page")
+     (widget-insert ".\n"))
     (slb
      (widget-insert "\
 Peaches Baur, 1986-1999.
@@ -1179,7 +1320,7 @@ Currently studying computer science in Trondheim, Norway.  Full time
 Linux user and proud of it.  XEmacs hacker light.
 
 See:\t")
-     (about-url-link 'stigb "Visit Stig's home page"))
+     (about-url-link 'stigb nil "Visit Stig's home page"))
     (thiessel
      (widget-insert "\
 Worked at University of Kaiserslautern where he took part in the
@@ -1212,25 +1353,40 @@ with in Austin, Texas - the Ether Bunnies.  I'm getting too old
 to play competitive Ultimate any more, so now I've gotten roped
 into serving on the board of directors of the Ultimate Players
 Association.  See ")
-     (about-url-link 'vin "Visit the UPA homepage")
+     (about-url-link 'vin nil "Visit the UPA homepage")
      (widget-insert ".\n"))
     (vladimir
      (widget-insert "\
-Former technical lead for XEmacs at Sun.  He is now with a startup
-marketing embedded Java databases.  See ")
-     (about-url-link 'vladimir "Visit Vladimir's home page")
+Former technical lead for XEmacs at Sun.  He is now writing a book on
+distributed Java and is working at Xerox PARC documenting AspectJ, a
+light-weight extension to Java that supports crosscutting concerns.
+See ")
+     (about-url-link 'vladimir nil "Visit Vladimir's home page")
      (widget-insert ".\n"))
     (wmperry
      (widget-insert "\
-Currently working at Aventail, Corp. on SOCKS v5 servers.\n"))
+Happily living in Indiana telecommuting for a company based in Seattle
+\(who I now prefer not to name), wishing I was in Ireland instead.\n"))
     (yoshiki
      (widget-insert
       "\
 Sorry, no personal information available about me yet.\n"))
     (youngs
-     (widget-insert
-      "\
-Sorry, no personal information available about me yet.\n"))
+     (widget-insert "\
+I live in Brisbane, Australia with my wife, Michelle and our daughter,
+Kaitlyn.  I've only been hacking XEmacs for a short time (approx 18
+mths), but I've been fooling around with computers since the early
+80's.
+
+In the past, I've been a bank officer, car salesman, insurance agent,
+managed a computer firm and owned and operated my own business.  I now
+divide my time between my family, planning my next business idea (a
+computer consulting firm that uses zero Microsoft products), looking
+after the XEmacs Packages and hacking my own XEmacs package, Eicq.
+
+\tSee: ")
+     (about-url-link 'youngs nil "Visit the Eicq homepage")
+     (widget-insert ".\n"))
     ))
 
 ;; Insert info about a maintainer's contribution to XEmacs.  See also
@@ -1266,11 +1422,17 @@ where the full power of the clipboard system is available under
 XEmacs).\n"))
     (baw
      (widget-insert "\
-Author of CC Mode for C, C++, Objective-C and Java editing, and
-Supercite for mail and news citing.  Also various and sundry other
-Emacs utilities, fixes, enhancements and kludgery as whimsy, boredom,
-and ToT dictate (but not necessarily in that order).  See also\n")
-     (about-url-link 'cc-mode "Visit the CC Mode distribution")
+I'm the author of ")
+     (about-url-link 'cc-mode "CC Mode" "Visit the CC Mode page")
+     (widget-insert ", for C, C++, Objective-C and Java editing,
+Supercite for mail and news citing, and sundry other XEmacs packages
+such as ELP (the Emacs Lisp Profiler), Reporter, xrdb-mode, and
+winring.  Even though I still live almost 100% in XEmacs these days,
+my Lisp hacking has fallen off in recent years as I became more
+involved in Python, and in fact, I currently maintain the Python
+editing mode.  See also: ")
+     (about-url-link "http://www.python.org/emacs" nil
+		     "Visit the python.org Emacs Goodies page")
      (widget-insert ".\n"))
     (ben
      (widget-insert
@@ -1295,7 +1457,7 @@ for software engineers.  It runs atop XEmacs and is available from
 his firm, BeOpen, which offers distributions, custom development,
 support, and training packages for corporate users of XEmacs, GNU
 Emacs and InfoDock.  See ")
-     (about-url-link 'beopen "Visit BeOpen WWW page")
+     (about-url-link 'beopen nil "Visit BeOpen WWW page")
      (widget-insert ".\n"))
     (cgw
      (widget-insert
@@ -1312,8 +1474,9 @@ Sorry, no information about my XEmacs contributions yet.\n"))
      (widget-insert
       "\
 Maintainer of XEmacs from mid-1994 through 1996.  Author of the
-redisplay engine and some of the device-abstraction, TTY and glyph
-code.  Creator of the xemacs.org domain.\n"))
+redisplay engine, the original toolbar and scrollbars and some of the
+device-abstraction, TTY and glyph code.  Creator of the xemacs.org
+domain and comp.emacs.xemacs.\n"))
     (daiki
      (widget-insert
       "\
@@ -1363,11 +1526,19 @@ reliable beta tester ever since.\n"))
     (fabrice
      (widget-insert
       "\
-Sorry, no information about my XEmacs contributions yet.\n"))
+I have started to provide binary kits for the 21.2 series when there
+was no installer available. I contributed a few lines of core code
+occasionally to make things smoother with the native win32 port which
+I'm using all the day.
+
+I also contributed elisp code long ago to make Gnus run under XEmacs.\n"))
     (golubev
      (widget-insert
       "\
-Sorry, no information about my XEmacs contributions yet.\n"))
+Used XEmacs since early 1997.  Fixed bugs that annoy me, both in
+XEmacs core and in packages I use, mostly viper.  Hoping to get
+coding-cookie package distributed, which is also a fix of what I
+consider a bug.\n"))
     (gunnar
      (widget-insert
       "\
@@ -1389,9 +1560,27 @@ early client of the external Emacs widget.\n"))
     (hniksic
      (widget-insert
       "\
-Hrvoje's contribution to XEmacs consists of a multitude of hours spent
-adding new features and bugs, and fixing old ones.  He dreams of
-writing a home page.\n"))
+Hrvoje's contribution to XEmacs consists of many hours spent working
+on code and taking part in public discussions.
+
+He wrote `savehist' and `htmlize' packages, the latter having a pretty
+large gathering of users.  He worked to improve many parts of XEmacs
+Lisp code, including isearch (FSF synch and new features), cl, edmacro
+\(FSF synch and an almost complete rewrite), profile, gnuserv,
+hyper-apropos, etags, about, and custom.
+
+He has worked on improving and optimizing the C core.  He ported many
+FSF core features such as indirect buffers, tty-erase-char,
+save-current-buffer and friends, debug-ignored-errors, etc.  He also
+wrote line numbering optimizations for large buffers, initial support
+for TTY frames, abbrev improvements, Lisp printer and reader
+improvements, support for extent modification functions, and lots of
+minor bugfixes, optimizations, and Muleifications.
+
+He contributed to Lispref and Internals documentation, including a
+section on writing Mule-compliant C code.  Maintains NEWS.  He
+participated on xemacs-beta since 1996 and on the Patch Review Board
+since its inception in 1998.\n"))
     (hobley
      (widget-insert
       "\
@@ -1412,7 +1601,9 @@ Beta tester, manager of the various XEmacs mailing lists and binary
 kit manager.  Also, originator and maintainer of the gnus.org domain.\n"))
     (jens
      (widget-insert "\
-Jens did the artwork for graphics added to XEmacs 20.2 and 19.15.\n"))
+Jens did the artwork for graphics added to XEmacs 20.2 and 19.15. He's
+also the author of \"XEmacs Mine\", a game similar to Minesweeper, but
+running in XEmacs\n"))
     (jmiller
      (widget-insert "\
 Beta tester and last hacker of calendar.\n"))
@@ -1422,7 +1613,8 @@ I started the native port of XEmacs to MS Windows. Author of the
 Windows frame, redisplay, face and event loop support.\n"))
     (juhp
      (widget-insert "\
-Author of \"find-func.el\" and improvements to \"help.el\".\n"))
+Author of \"find-func.el\", improvements to \"help.el\" and a good
+number of bug fixes during June 1997 to December 1998.\n"))
     (jwz
      (widget-insert
       "\
@@ -1491,9 +1683,10 @@ Author of the XEmacs Drag'n'Drop API.\n"))
       "\
 Author of the portable dumper.\n"))
     (oscar
-     (widget-insert
-      "\
-Author of the LDAP support in XEmacs.\n"))
+     (widget-insert "\
+Oscar's major contributions to XEmacs are the internal LDAP support
+and the EUDC package, an interface to query various directory services
+in a uniform manner (when composing mail for instance).\n"))
     (pelegri
      (widget-insert "\
 Author of EOS, a package included in the standard XEmacs distribution
@@ -1525,7 +1718,9 @@ Author of many extensions to the `extents' code, including the initial
 implementation of `duplicable' properties.\n"))
     (rossini
      (widget-insert "\
-Author of the first XEmacs FAQ.\n"))
+Author of the first XEmacs FAQ;
+Development lead on Emacs Speaks Statistics;
+Assisted Jareth Hein with setting up the JitterBug tracking system.\n"))
     (slb
      (widget-insert
       "\
@@ -1584,8 +1779,7 @@ strikethru face attribute support).\n"))
       "\
 Sorry, no information about my XEmacs contributions yet.\n"))
     (youngs
-     (widget-insert
-      "\
+     (widget-insert "\
 Maintainer and release manager of the packages.\n"))
     ))
 
